import { GraphQLResolveInfo } from 'graphql';
import { DocumentNode } from 'graphql';
export declare type Maybe<T> = T | null;
export declare type Exact<T extends {
    [key: string]: unknown;
}> = {
    [K in keyof T]: T[K];
};
export declare type MakeOptional<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]?: Maybe<T[SubKey]>;
};
export declare type MakeMaybe<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]: Maybe<T[SubKey]>;
};
export declare type RequireFields<T, K extends keyof T> = {
    [X in Exclude<keyof T, K>]?: T[X];
} & {
    [P in K]-?: NonNullable<T[P]>;
};
/** All built-in and custom scalars, mapped to their actual values */
export declare type Scalars = {
    ID: string;
    /** The `String` scalar type represents textual data, represented as UTF-8 character sequences. The String type is most often used by GraphQL to represent free-form human-readable text. */
    String: string;
    Boolean: boolean;
    /** The `Int` scalar type represents non-fractional signed whole numeric values. Int can represent values between -(2^31) and 2^31 - 1. */
    Int: number;
    /** The `Float` scalar type represents signed double-precision fractional values as specified by [IEEE 754](https://en.wikipedia.org/wiki/IEEE_floating_point). */
    Float: number;
};
export declare type Query = {
    /** POST /pull_expenses */
    getExpenses?: Maybe<getExpensesResponse>;
};
export declare type QuerygetExpensesArgs = {
    input: _queryInput_getExpenses_Input;
};
export declare type getExpensesResponse = {
    description: Scalars['String'];
    expenses?: Maybe<Array<Maybe<_query_getExpenses_expenses_items>>>;
    next_page?: Maybe<Scalars['String']>;
    result: Scalars['Int'];
    total_entries?: Maybe<Scalars['Int']>;
    total_pages?: Maybe<Scalars['String']>;
};
/** A Single Expense */
export declare type _query_getExpenses_expenses_items = {
    created_at: Scalars['String'];
    currency_symbol?: Maybe<_query_getExpenses_expenses_items_currency_symbol>;
    document_date?: Maybe<Scalars['String']>;
    document_id?: Maybe<Scalars['String']>;
    document_type?: Maybe<Scalars['String']>;
    file_name: Scalars['String'];
    file_url: Scalars['String'];
    foreign_total_for_payment?: Maybe<Scalars['Float']>;
    original_file_name?: Maybe<Scalars['String']>;
    provider: Scalars['String'];
    recognized_vat_payment: Scalars['Float'];
    remarks?: Maybe<Scalars['String']>;
    status_classification: Scalars['String'];
    system_id: Scalars['Int'];
    total_for_payment: Scalars['Float'];
    total_for_vat: Scalars['Float'];
    updated_at: Scalars['String'];
    vat_payment: Scalars['Float'];
};
export declare enum _query_getExpenses_expenses_items_currency_symbol {
    EUR = "EUR",
    USD = "USD"
}
export declare type _queryInput_getExpenses_Input = {
    api_user?: Maybe<Scalars['String']>;
    query_options?: Maybe<_query_options_Input>;
};
export declare type _query_options_Input = {
    updated_from?: Maybe<Scalars['String']>;
    updated_to?: Maybe<Scalars['String']>;
    created_from?: Maybe<Scalars['String']>;
    created_to?: Maybe<Scalars['String']>;
    document_date_from?: Maybe<Scalars['String']>;
    document_date_to?: Maybe<Scalars['String']>;
    document_id?: Maybe<Scalars['String']>;
    system_id?: Maybe<Scalars['Int']>;
    order?: Maybe<_query_options_order>;
    page?: Maybe<Scalars['Int']>;
    per_page?: Maybe<Scalars['Int']>;
};
export declare enum _query_options_order {
    document_date = "document_date"
}
export declare type WithIndex<TObject> = TObject & Record<string, any>;
export declare type ResolversObject<TObject> = WithIndex<TObject>;
export declare type ResolverTypeWrapper<T> = Promise<T> | T;
export declare type ResolverWithResolve<TResult, TParent, TContext, TArgs> = {
    resolve: ResolverFn<TResult, TParent, TContext, TArgs>;
};
export declare type LegacyStitchingResolver<TResult, TParent, TContext, TArgs> = {
    fragment: string;
    resolve: ResolverFn<TResult, TParent, TContext, TArgs>;
};
export declare type NewStitchingResolver<TResult, TParent, TContext, TArgs> = {
    selectionSet: string;
    resolve: ResolverFn<TResult, TParent, TContext, TArgs>;
};
export declare type StitchingResolver<TResult, TParent, TContext, TArgs> = LegacyStitchingResolver<TResult, TParent, TContext, TArgs> | NewStitchingResolver<TResult, TParent, TContext, TArgs>;
export declare type Resolver<TResult, TParent = {}, TContext = {}, TArgs = {}> = ResolverFn<TResult, TParent, TContext, TArgs> | ResolverWithResolve<TResult, TParent, TContext, TArgs> | StitchingResolver<TResult, TParent, TContext, TArgs>;
export declare type ResolverFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => Promise<TResult> | TResult;
export declare type SubscriptionSubscribeFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => AsyncIterator<TResult> | Promise<AsyncIterator<TResult>>;
export declare type SubscriptionResolveFn<TResult, TParent, TContext, TArgs> = (parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => TResult | Promise<TResult>;
export interface SubscriptionSubscriberObject<TResult, TKey extends string, TParent, TContext, TArgs> {
    subscribe: SubscriptionSubscribeFn<{
        [key in TKey]: TResult;
    }, TParent, TContext, TArgs>;
    resolve?: SubscriptionResolveFn<TResult, {
        [key in TKey]: TResult;
    }, TContext, TArgs>;
}
export interface SubscriptionResolverObject<TResult, TParent, TContext, TArgs> {
    subscribe: SubscriptionSubscribeFn<any, TParent, TContext, TArgs>;
    resolve: SubscriptionResolveFn<TResult, any, TContext, TArgs>;
}
export declare type SubscriptionObject<TResult, TKey extends string, TParent, TContext, TArgs> = SubscriptionSubscriberObject<TResult, TKey, TParent, TContext, TArgs> | SubscriptionResolverObject<TResult, TParent, TContext, TArgs>;
export declare type SubscriptionResolver<TResult, TKey extends string, TParent = {}, TContext = {}, TArgs = {}> = ((...args: any[]) => SubscriptionObject<TResult, TKey, TParent, TContext, TArgs>) | SubscriptionObject<TResult, TKey, TParent, TContext, TArgs>;
export declare type TypeResolveFn<TTypes, TParent = {}, TContext = {}> = (parent: TParent, context: TContext, info: GraphQLResolveInfo) => Maybe<TTypes> | Promise<Maybe<TTypes>>;
export declare type IsTypeOfResolverFn<T = {}, TContext = {}> = (obj: T, context: TContext, info: GraphQLResolveInfo) => boolean | Promise<boolean>;
export declare type NextResolverFn<T> = () => Promise<T>;
export declare type DirectiveResolverFn<TResult = {}, TParent = {}, TContext = {}, TArgs = {}> = (next: NextResolverFn<TResult>, parent: TParent, args: TArgs, context: TContext, info: GraphQLResolveInfo) => TResult | Promise<TResult>;
/** Mapping between all available schema types and the resolvers types */
export declare type ResolversTypes = ResolversObject<{
    Query: ResolverTypeWrapper<{}>;
    getExpensesResponse: ResolverTypeWrapper<getExpensesResponse>;
    String: ResolverTypeWrapper<Scalars['String']>;
    _query_getExpenses_expenses_items: ResolverTypeWrapper<_query_getExpenses_expenses_items>;
    _query_getExpenses_expenses_items_currency_symbol: _query_getExpenses_expenses_items_currency_symbol;
    Float: ResolverTypeWrapper<Scalars['Float']>;
    Int: ResolverTypeWrapper<Scalars['Int']>;
    _queryInput_getExpenses_Input: _queryInput_getExpenses_Input;
    _query_options_Input: _query_options_Input;
    _query_options_order: _query_options_order;
    Boolean: ResolverTypeWrapper<Scalars['Boolean']>;
}>;
/** Mapping between all available schema types and the resolvers parents */
export declare type ResolversParentTypes = ResolversObject<{
    Query: {};
    getExpensesResponse: getExpensesResponse;
    String: Scalars['String'];
    _query_getExpenses_expenses_items: _query_getExpenses_expenses_items;
    Float: Scalars['Float'];
    Int: Scalars['Int'];
    _queryInput_getExpenses_Input: _queryInput_getExpenses_Input;
    _query_options_Input: _query_options_Input;
    Boolean: Scalars['Boolean'];
}>;
export declare type QueryResolvers<ContextType = MeshContext, ParentType extends ResolversParentTypes['Query'] = ResolversParentTypes['Query']> = ResolversObject<{
    getExpenses?: Resolver<Maybe<ResolversTypes['getExpensesResponse']>, ParentType, ContextType, RequireFields<QuerygetExpensesArgs, 'input'>>;
}>;
export declare type getExpensesResponseResolvers<ContextType = MeshContext, ParentType extends ResolversParentTypes['getExpensesResponse'] = ResolversParentTypes['getExpensesResponse']> = ResolversObject<{
    description?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    expenses?: Resolver<Maybe<Array<Maybe<ResolversTypes['_query_getExpenses_expenses_items']>>>, ParentType, ContextType>;
    next_page?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    result?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    total_entries?: Resolver<Maybe<ResolversTypes['Int']>, ParentType, ContextType>;
    total_pages?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
}>;
export declare type _query_getExpenses_expenses_itemsResolvers<ContextType = MeshContext, ParentType extends ResolversParentTypes['_query_getExpenses_expenses_items'] = ResolversParentTypes['_query_getExpenses_expenses_items']> = ResolversObject<{
    created_at?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    currency_symbol?: Resolver<Maybe<ResolversTypes['_query_getExpenses_expenses_items_currency_symbol']>, ParentType, ContextType>;
    document_date?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    document_id?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    document_type?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    file_name?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    file_url?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    foreign_total_for_payment?: Resolver<Maybe<ResolversTypes['Float']>, ParentType, ContextType>;
    original_file_name?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    provider?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    recognized_vat_payment?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
    remarks?: Resolver<Maybe<ResolversTypes['String']>, ParentType, ContextType>;
    status_classification?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    system_id?: Resolver<ResolversTypes['Int'], ParentType, ContextType>;
    total_for_payment?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
    total_for_vat?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
    updated_at?: Resolver<ResolversTypes['String'], ParentType, ContextType>;
    vat_payment?: Resolver<ResolversTypes['Float'], ParentType, ContextType>;
    __isTypeOf?: IsTypeOfResolverFn<ParentType, ContextType>;
}>;
export declare type Resolvers<ContextType = MeshContext> = ResolversObject<{
    Query?: QueryResolvers<ContextType>;
    getExpensesResponse?: getExpensesResponseResolvers<ContextType>;
    _query_getExpenses_expenses_items?: _query_getExpenses_expenses_itemsResolvers<ContextType>;
}>;
import { MeshContext as BaseMeshContext, MeshInstance } from '@graphql-mesh/runtime';
import { SelectionSetParamOrFactory } from '@graphql-mesh/types';
export declare type QueryPayperSdk = {
    getExpenses: (params: {
        root?: any;
        args: QuerygetExpensesArgs;
        context: MeshContext;
        info: GraphQLResolveInfo;
        selectionSet?: SelectionSetParamOrFactory;
    }) => Promise<Query['getExpenses']>;
};
export declare type MutationPayperSdk = {};
export declare type SubscriptionPayperSdk = {};
export declare type PayperContext = {
    ["Payper"]: {
        Query: QueryPayperSdk;
        Mutation: MutationPayperSdk;
        Subscription: SubscriptionPayperSdk;
    };
};
export declare type MeshContext = PayperContext & BaseMeshContext;
import { GetMeshOptions } from '@graphql-mesh/runtime';
import { YamlConfig } from '@graphql-mesh/types';
import 'ts-node/register/transpile-only';
export declare const rawConfig: YamlConfig.Config;
export declare function getMeshOptions(): GetMeshOptions;
export declare const documentsInSDL: any[];
export declare function getBuiltMesh(): Promise<MeshInstance>;
export declare function getMeshSDK(): Promise<{
    getExpenses_query(variables: Exact<{
        input: _queryInput_getExpenses_Input;
    }>, options?: any): Promise<getExpenses_queryQuery>;
}>;
export declare type getExpenses_queryQueryVariables = Exact<{
    input: _queryInput_getExpenses_Input;
}>;
export declare type getExpenses_queryQuery = {
    getExpenses?: Maybe<(Pick<getExpensesResponse, 'description' | 'next_page' | 'result' | 'total_entries' | 'total_pages'> & {
        expenses?: Maybe<Array<Maybe<Pick<_query_getExpenses_expenses_items, 'created_at' | 'currency_symbol' | 'document_date' | 'document_id' | 'document_type' | 'file_name' | 'file_url' | 'foreign_total_for_payment' | 'original_file_name' | 'provider' | 'recognized_vat_payment' | 'remarks' | 'status_classification' | 'system_id' | 'total_for_payment' | 'total_for_vat' | 'updated_at' | 'vat_payment'>>>>;
    })>;
};
export declare const getExpenses_queryDocument: DocumentNode;
export declare type Requester<C = {}> = <R, V>(doc: DocumentNode, vars?: V, options?: C) => Promise<R>;
export declare function getSdk<C>(requester: Requester<C>): {
    getExpenses_query(variables: getExpenses_queryQueryVariables, options?: C): Promise<getExpenses_queryQuery>;
};
export declare type Sdk = ReturnType<typeof getSdk>;
